import { EventEmitter, OnChanges, OnInit, SimpleChanges, TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * A context for the
 * * `NgbPaginationFirst`
 * * `NgbPaginationPrevious`
 * * `NgbPaginationNext`
 * * `NgbPaginationLast`
 * * `NgbPaginationEllipsis`
 * * `NgbPaginationPages`
 *
 * link templates in case you want to override one.
 *
 * @since 4.1.0
 */
export interface DfxNgbPaginationLinkContext {
    /**
     * Page number displayed by the current link.
     */
    currentPage: number;
    /**
     * If `true`, the current link is disabled.
     */
    disabled: boolean;
}
/**
 * A context for the `NgbPaginationNumber` link template in case you want to override one.
 *
 * Extends `NgbPaginationLinkContext`.
 *
 * @since 4.1.0
 */
export interface DfxNgbPaginationNumberContext extends DfxNgbPaginationLinkContext {
    /**
     * The page number, displayed by the current page link.
     */
    $implicit: number;
}
/**
 * A context for the `NgbPaginationPages` pages template in case you want to override
 * the way all pages are displayed.
 *
 * @since 9.1.0
 */
export interface DfxNgbPaginationPagesContext {
    /**
     * The currently selected page number.
     */
    $implicit: number;
    /**
     * If `true`, pagination is disabled.
     */
    disabled: boolean;
    /**
     * Pages numbers that should be rendered starting with 1.
     */
    pages: number[];
}
/**
 * A directive to match the 'ellipsis' link template
 *
 * @since 4.1.0
 */
export declare class DfxNgbPaginationEllipsis {
    templateRef: TemplateRef<DfxNgbPaginationLinkContext>;
    constructor(templateRef: TemplateRef<DfxNgbPaginationLinkContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<DfxNgbPaginationEllipsis, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DfxNgbPaginationEllipsis, "ng-template[ngbPaginationEllipsis]", never, {}, {}, never>;
}
/**
 * A directive to match the 'first' link template
 *
 * @since 4.1.0
 */
export declare class DfxNgbPaginationFirst {
    templateRef: TemplateRef<DfxNgbPaginationLinkContext>;
    constructor(templateRef: TemplateRef<DfxNgbPaginationLinkContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<DfxNgbPaginationFirst, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DfxNgbPaginationFirst, "ng-template[ngbPaginationFirst]", never, {}, {}, never>;
}
/**
 * A directive to match the 'last' link template
 *
 * @since 4.1.0
 */
export declare class DfxNgbPaginationLast {
    templateRef: TemplateRef<DfxNgbPaginationLinkContext>;
    constructor(templateRef: TemplateRef<DfxNgbPaginationLinkContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<DfxNgbPaginationLast, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DfxNgbPaginationLast, "ng-template[ngbPaginationLast]", never, {}, {}, never>;
}
/**
 * A directive to match the 'next' link template
 *
 * @since 4.1.0
 */
export declare class DfxNgbPaginationNext {
    templateRef: TemplateRef<DfxNgbPaginationLinkContext>;
    constructor(templateRef: TemplateRef<DfxNgbPaginationLinkContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<DfxNgbPaginationNext, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DfxNgbPaginationNext, "ng-template[ngbPaginationNext]", never, {}, {}, never>;
}
/**
 * A directive to match the page 'number' link template
 *
 * @since 4.1.0
 */
export declare class DfxNgbPaginationNumber {
    templateRef: TemplateRef<DfxNgbPaginationNumberContext>;
    constructor(templateRef: TemplateRef<DfxNgbPaginationNumberContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<DfxNgbPaginationNumber, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DfxNgbPaginationNumber, "ng-template[ngbPaginationNumber]", never, {}, {}, never>;
}
/**
 * A directive to match the 'previous' link template
 *
 * @since 4.1.0
 */
export declare class DfxNgbPaginationPrevious {
    templateRef: TemplateRef<DfxNgbPaginationLinkContext>;
    constructor(templateRef: TemplateRef<DfxNgbPaginationLinkContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<DfxNgbPaginationPrevious, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DfxNgbPaginationPrevious, "ng-template[ngbPaginationPrevious]", never, {}, {}, never>;
}
/**
 * A directive to match the 'pages' whole content
 *
 * @since 9.1.0
 */
export declare class DfxNgbPaginationPages {
    templateRef: TemplateRef<DfxNgbPaginationPagesContext>;
    constructor(templateRef: TemplateRef<DfxNgbPaginationPagesContext>);
    static ɵfac: i0.ɵɵFactoryDeclaration<DfxNgbPaginationPages, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DfxNgbPaginationPages, "ng-template[ngbPaginationPages]", never, {}, {}, never>;
}
/** @docs-private */
declare const _DfxNgbPaginationBase: import("../core/constructor").Constructor<import("../core/disabled").CanDisable> & import("../core/constructor").AbstractConstructor<import("../core/disabled").CanDisable> & (new (...args: any[]) => import("../core/initialized").HasInitialized) & {
    new (): {};
};
/**
 * A component that displays page numbers and allows to customize them in several ways.
 */
export declare class DfxNgbPagination extends _DfxNgbPaginationBase implements OnInit, OnChanges {
    pageCount: number;
    pages: number[];
    private _initialized;
    tplEllipsis: DfxNgbPaginationEllipsis | undefined;
    tplFirst: DfxNgbPaginationFirst | undefined;
    tplLast: DfxNgbPaginationLast | undefined;
    tplNext: DfxNgbPaginationNext | undefined;
    tplNumber: DfxNgbPaginationNumber | undefined;
    tplPrevious: DfxNgbPaginationPrevious | undefined;
    tplPages: DfxNgbPaginationPages | undefined;
    /**
     * If `true`, pagination links will be disabled.
     */
    disabled: boolean;
    /**
     * If `true`, the "First" and "Last" page links are shown.
     */
    boundaryLinks: boolean;
    /**
     * If `true`, the "Next" and "Previous" page links are shown.
     */
    directionLinks: boolean;
    /**
     * If `true`, the ellipsis symbols and first/last page numbers will be shown when `maxSize` > number of pages.
     */
    ellipses: boolean;
    /**
     * Whether to rotate pages when `maxSize` > number of pages.
     *
     * The current page always stays in the middle if `true`.
     */
    rotate: boolean;
    /**
     *  The number of items in your paginated collection.
     *
     *  Note, that this is not the number of pages. Page numbers are calculated dynamically based on
     *  `collectionSize` and `pageSize`. Ex. if you have 100 items in your collection and displaying 20 items per page,
     *  you'll end up with 5 pages.
     */
    collectionSize: number;
    /**
     *  The maximum number of pages to display.
     */
    maxSize: number;
    /**
     *  The current page.
     *
     *  Page numbers start with `1`.
     */
    page: number;
    /**
     *  The number of items per page.
     */
    pageSize: number;
    /**
     *  An event fired when the page is changed. Will fire only if collection size is set and all values are valid.
     *
     *  Event payload is the number of the newly selected page.
     *
     *  Page numbers start with `1`.
     */
    pageChange: EventEmitter<number>;
    /**
     * The pagination display size.
     *
     * Bootstrap currently supports small and large sizes.
     */
    size: 'sm' | 'lg' | '';
    constructor();
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    hasPrevious(): boolean;
    hasNext(): boolean;
    nextDisabled(): boolean;
    previousDisabled(): boolean;
    selectPage(pageNumber: number): void;
    isEllipsis(pageNumber: number): boolean;
    /**
     * Appends ellipses and first/last page number to the displayed pages
     */
    private _applyEllipses;
    /**
     * Rotates page numbers based on maxSize items visible.
     * Currently selected page stays in the middle:
     *
     * Ex. for selected page = 6:
     * [5,*6*,7] for maxSize = 3
     * [4,5,*6*,7] for maxSize = 4
     */
    private _applyRotation;
    /**
     * Paginates page numbers based on maxSize items per page.
     */
    private _applyPagination;
    private _setPageInRange;
    private _updatePages;
    static ɵfac: i0.ɵɵFactoryDeclaration<DfxNgbPagination, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DfxNgbPagination, "dfx-ngb-pagination", never, { "disabled": "disabled"; "boundaryLinks": "boundaryLinks"; "directionLinks": "directionLinks"; "ellipses": "ellipses"; "rotate": "rotate"; "collectionSize": "collectionSize"; "maxSize": "maxSize"; "page": "page"; "pageSize": "pageSize"; "size": "size"; }, { "pageChange": "pageChange"; }, ["tplEllipsis", "tplFirst", "tplLast", "tplNext", "tplNumber", "tplPrevious", "tplPages"], never>;
}
export {};
